@@ -1,7 +1,7 @@
 import subprocess
 
 import click
-from typing import List
+from typing import List, Literal
 
 from loguru import logger
 
@@ -26,7 +26,7 @@ def cli():
 @click.option(
     "-i",
     "--install",
-    multiple=True,
+    is_flag=True,
     help="Install other dependencies of the package (not the inter/local dependencies)",
 )
 @click.option(
@@ -152,9 +152,40 @@ def publish(package: str, cwd: str = ""):
             pkg.publish()
 
 
+@click.command()
+@click.option("--cwd", default="", help="Override current working directory")
+@click.argument('subcommand')
+def git(cwd: str, subcommand: Literal["snapshot"]):
+    """Execute Git commands in a super-project"""
+    pbt_cfg = PBTConfig.from_dir(cwd)
+    cwd = str(pbt_cfg.cwd.absolute())
+
+    if subcommand == "snapshot":
+        # save current branch status of each
+        submodules = []
+
+        for dir in pbt_cfg.cwd.iterdir():
+            if not dir.is_dir():
+                continue
+            superdir = subprocess.check_output([
+                "git", "rev-parse", "--show-superproject-working-tree"
+            ], cwd=str(dir)).decode().strip()
+            if superdir == cwd:
+                submodules.append(dir)
+
+        for submodule_dir in submodules:
+            branch = subprocess.check_output([
+                "git", "rev-parse", "--abbrev-ref", "HEAD"
+            ], cwd=submodule_dir).decode().strip()
+            print(f"bash -c 'cd {submodule_dir}; git checkout {branch}; git pull'")
+    else:
+        raise Exception(f"Invalid subcommand: {subcommand}")
+
+
 cli.add_command(make)
 cli.add_command(publish)
-
+cli.add_command(update)
+cli.add_command(git)
 
 if __name__ == "__main__":
     cli()
